@@ -33,19 +33,12 @@ banner = r"""
     """
 
 help_menu = """
-    gtredactkit - Redact and Un-redact any sensitive data from your text files!
-
-    Github:\n
-    https://github.com/brootware/gtredactkit
-    
-    Follow me on Twitter!\n
-    https://twitter.com/brootware
-    
+    GtRedactKit - Redact and Un-redact any sensitive data from your text files!
     Example usage:\n
-        gtredactkit --text 'This is my ip: 127.0.0.1. My email is brute@gmail.com'\n
-        gtredactkit --file [file/filestoredact]\n
-        gtredactkit --file redacted_file --unredact .hashshadow.json\n
-        gtredactkit --file file --customfile custom.json\n
+        redactor --text 'This is my ip: 127.0.0.1. My email is brute@gmail.com'\n
+        redactor --file [file/filestoredact]\n
+        redactor --file redacted_file --unredact .hashshadow.json\n
+        redactor --file file --customfile custom.json\n
     """
 
 
@@ -61,6 +54,7 @@ def arg_helper() -> argparse.Namespace:
         nargs="*"
     )
     if len(sys.argv) == 1:
+        print(help_menu)
         parser.print_help(sys.stderr)
         sys.exit(1)
     parser.add_argument(
@@ -74,7 +68,7 @@ def arg_helper() -> argparse.Namespace:
         "--unredact",
         help="""
                 Option to unredact masked data.
-                Usage: gtredactkit -f [redacted_file] -u [.hashshadow.json]
+                Usage: redactor -f [redacted_file] -u [.hashshadow.json]
                 """
     )
     parser.add_argument(
@@ -82,7 +76,7 @@ def arg_helper() -> argparse.Namespace:
         "--dirout",
         help="""
                 Output directory of the file.
-                Usage: gtredactkit -f [file/filestoredact] -d [redacted_dir]
+                Usage: redactor -f [file/filestoredact] -d [redacted_dir]
                 """
     )
     parser.add_argument(
@@ -90,7 +84,7 @@ def arg_helper() -> argparse.Namespace:
         "--customfile",
         help="""
                 User defined custom regex pattern for redaction.
-                Usage: gtredactkit -f [file/filestoredact] -c [customfile.json]
+                Usage: redactor -f [file/filestoredact] -c [customfile.json]
                 """
     )
     parser.add_argument(
